@@ -6,7 +6,8 @@ import board
 import digitalio
 import adafruit_aw9523
 
-i2c = board.I2C()
+i2c = board.I2C()  # uses board.SCL and board.SDA
+# i2c = board.STEMMA_I2C()  # For using the built-in STEMMA QT connector on a microcontroller
 aw = adafruit_aw9523.AW9523(i2c)
 
 led_pin = aw.get_pin(0)  # LED on AW9523 io 0
